@@ -2,6 +2,8 @@ from ._history import HistoryRepository, HistoryRequest, HistoryResponse
 from ._mock import Mock
 from ._remote_handler import RemoteHandler
 from ._remote_mock import RemoteMock
+from ._system_log_filter import SystemLogFilter
 
 __all__ = ("Mock", "RemoteMock", "RemoteHandler",
-           "HistoryRepository", "HistoryRequest", "HistoryResponse",)
+           "HistoryRepository", "HistoryRequest", "HistoryResponse",
+           "SystemLogFilter",)
